@@ -40,23 +40,28 @@ def load_hdf5s(hdf5_locs: List):
     prediction_metadata = []
     template_label_cols = None  # will use this var to check consistency of label_cols across each hdf5_loc
     for loc in hdf5_locs:
-        with h5py.File(loc, 'r') as f:
-            logging.debug(f.keys())
-            these_predictions = f['predictions'][:]
-            these_prediction_metadata = {
-                'id_str': f['id_str'].asstr()[:],
-                'hdf5_loc': [os.path.basename(loc) for _ in these_predictions]
-        }
-            predictions.append(these_predictions)  # will create a list where each element is 3D predictions stored in each hdf5
-            prediction_metadata.append(these_prediction_metadata)  # also track id_str, similarly
+        try:
+            with h5py.File(loc, 'r') as f:
 
-            if template_label_cols is None:  # first file to load, use this as the expected template
-                template_label_cols = f['label_cols'].asstr()[:]
-                logging.info('Using label columns {} from first hdf5 {}'.format(template_label_cols, loc))
-            else:
-                these_label_cols = f['label_cols'].asstr()[:]
-                if any(these_label_cols != template_label_cols):
-                    raise ValueError('Label columns {} of hdf5 {} do not match first label columns {}'.format(loc, f['label_cols'], template_label_cols))
+                    logging.debug(f.keys())
+                    these_predictions = f['predictions'][:]
+                    these_prediction_metadata = {
+                        'id_str': f['id_str'].asstr()[:],
+                        'hdf5_loc': [os.path.basename(loc) for _ in these_predictions]
+                }
+                    predictions.append(these_predictions)  # will create a list where each element is 3D predictions stored in each hdf5
+                    prediction_metadata.append(these_prediction_metadata)  # also track id_str, similarly
+
+                    if template_label_cols is None:  # first file to load, use this as the expected template
+                        template_label_cols = f['label_cols'].asstr()[:]
+                        logging.info('Using label columns {} from first hdf5 {}'.format(template_label_cols, loc))
+                    else:
+                        these_label_cols = f['label_cols'].asstr()[:]
+                        if any(these_label_cols != template_label_cols):
+                            raise ValueError('Label columns {} of hdf5 {} do not match first label columns {}'.format(loc, f['label_cols'], template_label_cols))
+        except Exception as e:
+            logging.critical('Failed to load {}'.format(loc))
+            raise e
 
 
     # there is no assumption that id_str is unique, or attempt to group predictions by id_str
@@ -88,7 +93,6 @@ def prediction_hdf5_to_summary_parquet(hdf5_loc: str, save_loc: str, schema: sch
     """
     assert isinstance(hdf5_loc, str)
 
-    label_cols = schema.label_cols
 
     # concentrations will be of (galaxy, question, model, forward_pass) after going through c_group
     # may be only one model but will still have that dimension (e.g. 1000, 39, 1, 5)
@@ -100,6 +104,12 @@ def prediction_hdf5_to_summary_parquet(hdf5_loc: str, save_loc: str, schema: sch
         galaxy_id_df = galaxy_id_df[:100000]
         save_loc = save_loc.replace('.parquet', '_debug.parquet')
 
+    label_cols = schema.label_cols
+    # TODO optionally ignore all but a subset of columns, for models without finetuning
+    # hdf5_label_cols = label_cols
+    # valid_cols = [col for col in hdf5_label_cols if col in label_col_subset]
+    # concentrations = concentrations[:, valid_cols]
+
     # applies to all questions at once
     # hopefully also supports 3D concentrations (galaxy/question/model/pass)
     logging.info('Concentrations: {}'.format(concentrations.shape))
